@@ -21,7 +21,7 @@
  * This include file features all the definitions that should
  * be externally visible. This isn't much.
  *
- * $Id: uudeview.h,v 1.4 2002/04/06 01:53:30 root Exp $
+ * $Id$
  */
 
 #ifndef _ANSI_ARGS_
@@ -88,6 +88,8 @@
  * Option indices for GetOption / SetOption
  */
 
+#define UUOPT_RBUF	(90)    /* file read I/O buffer size */
+#define UUOPT_WBUF	(91)    /* file write I/O buffer size */
 #define UUOPT_VERSION	(0)	/* version number MAJOR.MINORplPATCH (ro) */
 #define UUOPT_FAST	(1)	/* assumes only one part per file */
 #define UUOPT_DUMBNESS	(2)	/* switch off the program's intelligence */
@@ -210,6 +212,7 @@ int	UUEXPORT UUSetFileNameCallback	_ANSI_ARGS_((void *,
 								 char *, char *)));
 char *	UUEXPORT UUFNameFilter		_ANSI_ARGS_((char *));
 int	UUEXPORT UULoadFile		_ANSI_ARGS_((char *, char *, int, int *));
+int	UUEXPORT UULoadFileWithPartNo	_ANSI_ARGS_((char *, char *, int, int, int *));
 uulist *UUEXPORT UUGetFileListItem	_ANSI_ARGS_((int));
 int	UUEXPORT UURenameFile		_ANSI_ARGS_((uulist *, char *));
 int	UUEXPORT UUDecodeToTemp		_ANSI_ARGS_((uulist *));
@@ -230,7 +233,8 @@ int	UUEXPORT UUEncodeMulti		_ANSI_ARGS_((FILE *, FILE *,
 int	UUEXPORT UUEncodePartial	_ANSI_ARGS_((FILE *, FILE *,
 						     char *, int,
 						     char *, char *,
-						     int, int, long));
+						     int, int, long,
+						     unsigned long*));
 int	UUEXPORT UUEncodeToStream	_ANSI_ARGS_((FILE *, FILE *,
 						     char *, int,
 						     char *, int));
